=====
Usage
=====

To use ISLEX pronunciation dictionary accessors in a project::

    from islex.data.periphery import entries_stream

which provides a streaming iterator over the entries provided here.

.. automodule:: islex.data.periphery
    :members:
    :undoc-members:
    :show-inheritance:
